@@ -225,6 +225,6 @@ def query_by_key_min_max(key_condition, table_name, is_min, dynamodb):
 def get_all_items_in_table(table_name, dynamodb):
   try:
     table = dynamodb.Table(table_name)
-    return table.scan().get('Item', None)
+    return table.scan()['Items']
   except ClientError as e:
     raise DynamoDBError(e.response['Error']['Message'])
\ No newline at end of file
