@@ -22,7 +22,7 @@ db.create_metric(
   first = int(time.time()-100), last = int(time.time()), data_points_list = [], dynamodb=dynamodb
 )'''
 
-a = db.get_metric_details('test6', dynamodb)
+a = db.get_all_items_in_table('org.info', dynamodb)
 print(a)
 #a = db.query_most_recent_metric_fetching_log('prd_db_2', dynamodb)
 #print(a['last_fetched_ts'])
\ No newline at end of file
